/* 
 * Licensed to Aduna under one or more contributor license agreements.  
 * See the NOTICE.txt file distributed with this work for additional 
 * information regarding copyright ownership. 
 *
 * Aduna licenses this file to you under the terms of the Aduna BSD 
 * License (the "License"); you may not use this file except in compliance 
 * with the License. See the LICENSE.txt file distributed with this work 
 * for the full License.
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or 
 * implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package org.openrdf.query.resultio;

import java.io.OutputStream;

/**
 * Returns {@link TupleQueryResultWriter}s for a specific tuple query result
 * format.
 * 
 * @author Arjohn Kampman
 */
public interface TupleQueryResultWriterFactory {

	/**
	 * Returns the tuple query result format for this factory.
	 */
	public TupleQueryResultFormat getTupleQueryResultFormat();

	/**
	 * Returns a TupleQueryResultWriter instance that will write to the supplied
	 * output stream.
	 * 
	 * @param out
	 *        The OutputStream to write the result to.
	 */
	public TupleQueryResultWriter getWriter(OutputStream out);
}
